@@ -1,4 +1,4 @@
-## Copyright (c) 2015, James P. Howard, II <jh@jameshoward.us>
+## Copyright (c) 2015-2019, James P. Howard, II <jh@jameshoward.us>
 ##
 ## Redistribution and use in source and binary forms, with or without
 ## modification, are permitted provided that the following conditions are
@@ -32,6 +32,7 @@
 #' @param word string or vector of strings to encode
 #' @param maxCodeLen   maximum length of the resulting encodings, in characters
 #' @param modified     if \code{TRUE}, use the Caverphone 2 algorithm
+#' @param clean if \code{TRUE}, return \code{NA} for unknown alphabetical characters
 #'
 #' @details
 #'
@@ -42,12 +43,17 @@
 #' The variable \code{modified} directs \code{caverphone} to use the
 #' Caverphone2 method, instead of the original.
 #'
-#' @return the Caverphone encoded character vector
+#' The \code{caverphone} algorithm is only defined for inputs over the
+#' standard English alphabet, \emph{i.e.}, "A-Z.". Non-alphabetical
+#' characters are removed from the string in a locale-dependent fashion.
+#' This strips spaces, hyphens, and numbers.  Other letters, such as
+#' "Ü," may be permissible in the current locale but are unknown to
+#' \code{caverphone}.  For inputs outside of its known range, the output is
+#' undefined and \code{NA} is returned and a \code{warning} this thrown.
+#' If \code{clean} is \code{FALSE}, \code{caverphone} attempts to process the
+#' strings.  The default is \code{TRUE}.
 #'
-#' @section Caveats:
-#' The \code{caverphone} algorithm is only
-#' defined for inputs over the standard English alphabet, \emph{i.e.},
-#' "A-Z." For inputs outside this range, the output is undefined.
+#' @return the Caverphone encoded character vector
 #'
 #' @references
 #'
@@ -65,7 +71,7 @@
 #' caverphone("Stevenson", maxCodeLen = 4)
 #'
 #' @export
-caverphone <- function(word, maxCodeLen = NULL, modified = FALSE) {
+caverphone <- function(word, maxCodeLen = NULL, modified = FALSE, clean = TRUE) {
     ## From here on, this is a line-for-line translation of the Apache
     ## Commons Caverphone and Caverphone2 implementations, which both
     ## used regular expressions for substantially all of the work.
@@ -77,9 +83,13 @@ caverphone <- function(word, maxCodeLen = NULL, modified = FALSE) {
         else
             maxCodeLen <- 6
 
-    ## First, remove any nonalphabetical characters and lowercase it
-    word <- gsub("[^[:alpha:]]*", "", word, perl = TRUE)
+    ## First, uppercase it and test for unprocessable characters
     word <- tolower(word)
+    listNulls <- is.null(word)
+    listNAs <- is.na(word)
+    if(any(nonalpha <- grepl("[^a-z]", word, perl = TRUE)) && clean)
+        warning("unknown characters found, results may not be consistent")
+    word <- gsub("[^a-z]*", "", word, perl = TRUE)
 
     if(modified == TRUE)
         word <- caverphone_modified(word)
@@ -87,8 +97,17 @@ caverphone <- function(word, maxCodeLen = NULL, modified = FALSE) {
         word <- caverphone_original(word)
 
     ## Pad the wording with maxCodeLen 1s and truncate
-	word <- gsub("$", paste(rep(1, maxCodeLen), collapse = ""), word, perl = TRUE)
+    ones <- paste(rep(1, maxCodeLen), sep = "", collapse = "")
+    word <- gsub("$", ones, word, perl = TRUE)
     word <- substr(word, 1, maxCodeLen)
+    word <- gsub(ones, "", word, perl = TRUE)
+
+    ## Yeah, we already processed them, but now get rid of them
+    word[listNulls] <- NA
+    word[listNAs] <- NA
+    if(clean)
+        word[nonalpha] <- NA
+
     return(word)
 }
 
@@ -213,7 +232,7 @@ caverphone_modified <- function(word) {
     word <- gsub("l", "2", word, perl = TRUE)
     word <- gsub("2", "", word, perl = TRUE)
     word <- gsub("3$", "A", word, perl = TRUE)
-	word <- gsub("3", "", word, perl = TRUE)
+    word <- gsub("3", "", word, perl = TRUE)
 
     return(word)
 }
