@@ -1,4 +1,4 @@
-## Copyright (c) 2015, James P. Howard, II <jh@jameshoward.us>
+## Copyright (c) 2015-2019, James P. Howard, II <jh@jameshoward.us>
 ##
 ## Redistribution and use in source and binary forms, with or without
 ## modification, are permitted provided that the following conditions are
@@ -31,19 +31,25 @@
 #'
 #' @param word string or vector of strings to encode
 #' @param maxCodeLen   maximum length of the resulting encodings, in characters
-#'
+#' @param clean if \code{TRUE}, return \code{NA} for unknown alphabetical characters
+#' 
 #' @details
 #'
 #' The variable \code{word} is the name to be encoded.  The variable
 #' \code{maxCodeLen} is the limit on how long the returned name code
 #' should be.  The default is 4.
 #'
-#' @return the Lein encoded character vector
+#' The \code{lein} algorithm is only defined for inputs over the
+#' standard English alphabet, \emph{i.e.}, "A-Z.". Non-alphabetical
+#' characters are removed from the string in a locale-dependent fashion.
+#' This strips spaces, hyphens, and numbers.  Other letters, such as
+#' "Ü," may be permissible in the current locale but are unknown to
+#' \code{lein}.  For inputs outside of its known range, the output is
+#' undefined and \code{NA} is returned and a \code{warning} this thrown.
+#' If \code{clean} is \code{FALSE}, \code{lein} attempts to process the
+#' strings.  The default is \code{TRUE}.
 #'
-#' @section Caveats:
-#' The \code{lein} algorithm is only
-#' defined for inputs over the standard English alphabet, \emph{i.e.},
-#' "A-Z." For inputs outside this range, the output is undefined.
+#' @return the Lein encoded character vector
 #'
 #' @references
 #'
@@ -60,11 +66,15 @@
 #' lein("Stevenson", maxCodeLen = 8)
 #'
 #' @export
-lein <- function(word, maxCodeLen = 4) {
+lein <- function(word, maxCodeLen = 4, clean = TRUE) {
 
-    ## First, remove any nonalphabetical characters and uppercase it
-    word <- gsub("[^[:alpha:]]*", "", word, perl = TRUE)
+    ## First, uppercase it and test for unprocessable characters
     word <- toupper(word)
+    listNulls <- is.null(word)
+    listNAs <- is.na(word)
+    if(any(nonalpha <- grepl("[^A-Z]", word, perl = TRUE)) && clean)
+        warning("unknown characters found, results may not be consistent")
+    word <- gsub("[^A-Z]*", "", word, perl = TRUE)
 
     ## First character of key = first character of name
     first <- substr(word, 1, 1)
@@ -101,6 +111,12 @@ lein <- function(word, maxCodeLen = 4) {
     ## Manage some edge cases
     word <- sub("0000", "", word, perl = TRUE)
 
+    ## Yeah, we already processed them, but now get rid of them
+    word[listNulls] <- NA
+    word[listNAs] <- NA
+    if(clean)
+        word[nonalpha] <- NA
+
     return(word)
 }
 
